@@ -216,8 +216,7 @@ void ProcessTableView::openExecDirWithFM()
                     QString output(whichProcess.readAllStandardOutput());
 
                     QDir flatpakRootDir(output.split("Location:")[1].split("\n")[0].simplified());
-                    if (flatpakRootDir.cd("files") && flatpakRootDir.cd("bin"))
-                    {
+                    if (flatpakRootDir.cd("files") && flatpakRootDir.cd("bin")) {
                         // Need split full path to get last filename.
                         const QString &path = QString(flatpakRootDir.absoluteFilePath(cmdline.split("/").last())).trimmed();
                         common::openFilePathItem(path);
@@ -882,7 +881,7 @@ void ProcessTableView::customizeProcessPriority()
     QString prio {"0"};
     if (m_selectedPID.isValid()) {
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
-        slider->setValue(m_model->getProcessPriority(pid));
+        slider->setValue(m_model->getProcessPriorityValue(pid));
         prio = QString("%1").arg(slider->value());
         slider->setTipValue(prio);
     }
