@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
 <context>
     <name>App.About</name>
     <message>
@@ -771,6 +771,13 @@ Segur que voleu continuar?</translation>
         <translation>Tots els processos</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Es carrega</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +984,12 @@ Segur que voleu continuar?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>D&apos;acord</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Cancel·la</translation>
     </message>
 </context>
@@ -1102,4 +1111,4 @@ Segur que voleu continuar?</translation>
         <translation>Serveis</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
