@@ -771,6 +771,13 @@ Sind Sie sicher, dass Sie fortfahren wollen?</translation>
         <translation>Alle Prozesse</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -1102,4 +1109,4 @@ Sind Sie sicher, dass Sie fortfahren wollen?</translation>
         <translation>Dienste</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
