@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
 <context>
     <name>App.About</name>
     <message>
@@ -771,6 +771,13 @@ Haluatko varmasti jatkaa?</translation>
         <translation>Kaikki prosessit</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Ladataan</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -977,10 +984,12 @@ Haluatko varmasti jatkaa?</translation>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Peru</translation>
     </message>
 </context>
@@ -1102,4 +1111,4 @@ Haluatko varmasti jatkaa?</translation>
         <translation>Palvelut</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
